'******************************************************************************
'*  io.spin - handle input and output requests sent by pm80
'*
'*  (c) Juergen Buchmueller <pullmoll@t-online.de>
'*
'* $Id: io.spin,v 1.20 2010-03-25 09:40:35 pm Exp $
'******************************************************************************
CON

	io_cmd_out		=	$01		' I/O emulator command output
	io_cmd_in		=	$02		' I/O emulator command input
	io_cmd_break		=	$03		' I/O emulator command break
	io_cmd_kbd		=	$04		' I/O emulator command read TRS-80 keyboard

	constat			=	$10		' (16)sio port 1 status port
	condata			=	$11		' (17)sio port 1 data port
	punstat			=	$12		' (18)sio port 2 status port
	pundata			=	$13		' (19)sio port 2 data port

	myname_port		=	$70		' hopefully not used by anything else
	port2_Off		=	$71		' a little CP/M program sends an OUT to port &H71
	Forecolor		=	$72		' set foreground color
	Backcolor		=	$73		' set background color
	keystat			=	$74		' test just keyboard status (constat does this, too)
	keydata			=	$75		' get just the keyboard character

	port2_io		=	$78		' for input and output to port 2
	port2_test		=	$7D		' to test if a byte is ready
	port2_baud		=	$7C		' set baud rate multiple of 1200 eg 1=1200, 16=19200, 96=115200

	baud			=	115200		' baud rate
	fdx_size		=	32		' size of the rx and tx buffer (see FullDuplexSerial_rr004.spin)

	_nul			=	0		' clear screen code
	_cr			=	13		' carriage return
	dir_none		=	0		' no i/o direction selected
	dir_out			=	1		' expecting client to write to the port
	dir_in			=	2		' expecting client to read from the port

'#define VERBOSE

VAR
	long	cog
	long	io_command
	long	io_port
	long	io_data
	byte	de[32]					' directory entry
	byte	name[12+1]
	byte	datetime[20+1]

OBJ
	fdx	: "FullDuplexSerial_rr004"
	kbd	: "Keyboard"
	fat	: "fatfs"
#ifdef TriBladeProp
	xmm	: "TriBladeProp_Blade2_204"		' Extended memory manager
#endif
#ifdef RamBladeProp
	xmm	: "RamBlade_203_002"			' Extended memory manager
#endif
#ifdef DracBladeProp
	xmm	: "Dracblade"				' Extended memory manager
#endif

PUB start(SI, SO, doPin, clkPin, diPin, csPin, kbDpin, kbCpin, screen) : okay | i, dent, sec
	stop

	' wait 2 seconds
	waitcnt(CNT + clkfreq * 2)

	screen_ptr := screen

	okay := fdx.start(SI, SO, 0, baud)
	if okay < 0
		return

	i :=  fdx.params
	rx_head := i
	rx_tail := i + constant(1*4)
	tx_head := i + constant(2*4)
	tx_tail := i + constant(3*4)
	rx_buffer := i + constant(9*4)
	tx_buffer := i + constant(9*4) + constant(fdx_size)

	str(string("YAZ80 - Yet Another Z80..."))
	crlf

	okay := \kbd.startx(kbDpin, kbCpin, %100, 40)
	if okay < 0
		str(string("Keyboard failed: "))
		dec(okay)
		crlf
		return
	str(string("Keyboard initialized"))
	crlf
	kbd_states := kbd.states_ptr
	kbd_change := kbd.change_ptr

	okay := \fat.start(doPin, clkPin, diPin, csPin)
	if okay < 0
		str(string("sdspi + FAT failed: "))
		dec(okay)
		crlf
		return
	str(string("sdspi + FAT initialized"))
	crlf

	iobuff_ptr := fat.get_iobuff

	okay := xmm.start
	if okay < 0
#ifdef TriBladeProp
		str(string("TriBladeProp XMM failed: "))
#endif
#ifdef RamBladeProp
		str(string("RamBladeProp XMM failed: "))
#endif
#ifdef DracBladeProp
		str(string("DracBladeProp XMM failed: "))
#endif
		dec(okay)
		crlf
		return
#ifdef TriBladeProp
	str(string("TriBladeProp XMM initialized"))
#endif
#ifdef RamBladeProp
	str(string("RamBladeProp XMM initialized"))
#endif
#ifdef DracBladeProp
	str(string("DracBladeProp XMM initialized"))
#endif
	crlf

	' clear the Z80 RAM
	longfill(iobuff_ptr, 0, 512/4)
	repeat i from $4000 to $fe00 step $200
		xmm.DoCmd("W", iobuff_ptr, i, $200)

	okay := fat.mount
	if okay < 0
		str(string("FAT mount failed: "))
		dec(okay)
		crlf
		return
	str(string("Directory entries: "))
	dec(fat.get_dir_size)
	crlf

	dent := open_file(string("TRS80.ROM"))
	if dent < 0
		return -1
	sec := fat.get_dent_first_sector(de)
	repeat i from $0000 to $2e00 step $200
		fat.read_sector(sec, iobuff_ptr, $200)
		xmm.DoCmd("W", iobuff_ptr, i, $200)
		sec := fat.get_dent_next_sector(de, sec)

	cmd_load(string("GALAXY.CMD"))

	okay := fat.stop
	if okay < 0
		str(string("fat stop failed"))
		crlf
		return -1

	okay := cog := COGNEW(@entry, @io_command) + 1
	if okay =< 0
		str(string("io start failed"))
		crlf
		return -1
	str(string("io initialized"))
	crlf

	return 0

PUB stop
'' Stop CPU simulator - frees a cog
	if cog
		cogstop(cog~ - 1)

PRI open_file(fname_ptr) : dent | size, sec
	bytemove(@name, fname_ptr, 12)
	dent := fat.find_file(@name)
	if dent < 0
		str(@name)
		str(string(" not found."))
		crlf
		return -1
	bytemove(de, dent, 32)
	size := fat.get_dent_size(de)
	sec := fat.get_dent_first_sector(de)
	fat.get_dent_date_time(de, @datetime)
	str(@name)
	str(string(": sector "))
	dec(sec)
	str(string(9,"size "))
	dec_size(size)
	fdx.tx(9)
	str(@datetime)
	crlf

PRI cmd_load(fname_ptr) | dent, sec, nsec, addr, state, badr, blen, bmin, bmax
	dent := open_file(fname_ptr)
	if dent < 0
		return -1
	sec := fat.get_dent_first_sector(de)

	addr := $200
	state := 0
	bmin := $ffff
	bmax := $0000
	repeat
		if addr == $200
			if sec < 0
				quit
			nsec := fat.get_dent_next_sector(de, sec)
			fat.read_sector(sec, iobuff_ptr, $200)
			sec := nsec
			addr := 0
		case state
			0:	' expecting a header
				case byte[iobuff_ptr][addr++]
					$01:	' CMD load block header
						state := 1
					$02:	' CMD entry point header
						state := 7
					other:	' CMD comment block
						state := 5

			1:	' expecting a block length
				blen := byte[iobuff_ptr][addr++]
				state := 2

			2:	' expecting address LSB
				blen--
				badr := byte[iobuff_ptr][addr++]
				state := 3

			3:	' expecting address MSB
				blen--
				badr += 256 * byte[iobuff_ptr][addr++]
				state := 4
				if blen =< 0
					blen += 256
				bmin := bmin <# badr

			4:	' expecting blen bytes of data
				xmm.DoCmd("W", iobuff_ptr + addr, badr, 1)
				badr++
				addr++
				blen--
				if blen == 0
					bmax := bmax #> badr
					state := 0

			5:	' expecting a block length
				blen := byte[iobuff_ptr][addr++]
				if blen == 0
					blen := 256
				state := 6

			6:	' ignoring comment data
				addr++
				blen--
				if blen == 0
					state := 0

			7:	' expecting a block length
				blen := byte[iobuff_ptr][addr++]
				state := 8

			8:	' expecting entry point LSB
				blen--
				badr := byte[iobuff_ptr][addr++]
				state := 9

			9:	' expecting entry point MSB
				blen--
				badr += 256 * byte[iobuff_ptr][addr++]
				str(string("Loaded from "))
				hex(bmin, 4)
				str(string(".."))
				hex(bmax - 1, 4)
				crlf
				str(string("Entry point "))
				hex(badr, 4)
				crlf
				xmm.DoCmd("W", @badr, $0003, 2)
				quit


PRI str(str_ptr) | i
	repeat i from 0 to strsize(str_ptr) - 1
		fdx.tx(byte[str_ptr][i])

PRI crlf
	fdx.tx(13)
	fdx.tx(10)

PRI dec_size(value)
	if value > 1048576
		dec(value/1048576)
		fdx.tx(".")
		dec(10*(value // 1048576) / 1048576)
		str(string("MB"))
	elseif value > 1024
		dec(value/1024)
		fdx.tx(".")
		dec(10*(value // 1024) / 1024)
		str(string("KB"))
	else
		dec(value)

PRI dec(value) | _i
'' Print a decimal number

	if value < 0
		-value
		fdx.tx("-")

	_i := 1_000_000_000

	repeat 10
		if value => _i
			fdx.tx(value / _i + "0")
			value //= _i
			result~~
		elseif result or _i == 1
			fdx.tx("0")
		_i /= 10

PRI dech(value) | _i
'' Print a decimal number with 1000s tick marks

	if value < 0
		-value
		fdx.tx("-")

	_i := 1_000_000_000

	repeat 10
		if value => _i
			if _i == 100_000_000 or _i == 100_000 or _i == 100
				fdx.tx("'")
			fdx.tx(value / _i + "0")
			value //= _i
			result~~
		elseif result or _i == 1
			if _i == 100_000_000 or _i == 100_000 or _i == 100
				fdx.tx("'")
			fdx.tx("0")
		_i /= 10

PRI hex(value, digits)
'' Print a hexadecimal number

	value <<= (8 - digits) << 2
	repeat digits
		fdx.tx(lookupz((value <-= 4) & $F : "0".."9", "A".."F"))

PRI bin(value, digits)
'' Print a binary number

	value <<= 32 - digits
	repeat digits
		fdx.tx((value <-= 1) & 1 + "0")

PUB command_addr
'' Return the address of the 3 longs block
	return @io_command

DAT
'---------------------------------------------------------------------------------------------------------

		org	0

'---------------------------------------------------------------------------------------------------------
entry
io_command_ptr	mov	io_command_ptr, PAR
io_port_ptr	mov	io_port_ptr, PAR
io_data_ptr	add	io_port_ptr, #4
first_run	mov	io_data_ptr, PAR
		add	io_data_ptr, #8
		jmp	#run

' FullDuplexSerial
rx_head		long	0-0
rx_tail		long	0-0
tx_head		long	0-0
tx_tail		long	0-0
rx_buffer	long	0-0
tx_buffer	long	0-0
fdx_t1		long	0
fdx_t2		long	0
fdx_t3		long	0

screen_ptr	long	0-0

iobuff_ptr	long	0-0

kbd_lookup	long	@@@kbd_lookup_table
kbd_rows	long	@@@kbd_rows_table
kbd_states	long	0-0
kbd_change	long	0-0
kbd_index	long	0
kbd_shift	long	0
kbd_data	long	0

minus1		long	$ffffffff
msg_break_ptr	long	@@@msg_break

wait		long	0
port		long	0
data		long	0
null		long	0

t1		long	0
t2		long	0
t3		long	0

strptr		long	0
hexval		long	0
hexcnt		long	0

run
		wrlong	null, io_command_ptr
command
		rdlong	t1, kbd_change		WZ
	if_nz	jmp	#keyboard
		rdlong	wait, io_command_ptr	WZ
	if_z	jmp	#command
		cmp	wait, #io_cmd_out	WZ
	if_z	jmp	#output
		cmp	wait, #io_cmd_in	WZ
	if_z	jmp	#input
		cmp	wait, #io_cmd_break	WZ
	if_z	jmp	#break
		cmp	wait, #io_cmd_kbd	WZ
	if_z	jmp	#key_matrix
command_0
		wrlong	null, io_command_ptr
		jmp	#command

'*******************************************
'
' Read i/o port and data to write to
'
output
		rdlong	port, io_port_ptr
		rdlong	data, io_data_ptr
		and	port, #$ff
		cmp	port, #condata WZ	' console output?
	if_z	jmp	#output_conout
		cmp	port, #punstat WZ	' really?
	if_z	jmp	#output_punstat
		cmp	port, #pundata WZ	' punch output?
	if_z	jmp	#output_pundata
		jmp	#command_0

'*******************************************
'
' Write data to the console
'
output_conout
		and	data, #$ff
		call	#tx
		jmp	#command_0

'*******************************************
'
' Write data to the FullDuplexSerial tx_buffer
'
tx
:wait		rdlong	fdx_t1, tx_head
		mov	fdx_t3, fdx_t1
		add	fdx_t1, #1
		rdlong	fdx_t2, tx_tail
		and	fdx_t1, #fdx_size-1
		cmp	fdx_t1, fdx_t2 WZ
	if_z	jmp	#:wait			' wait until there's room in the buffer
		add	fdx_t3, tx_buffer
		wrbyte	data, fdx_t3
		wrlong	fdx_t1, tx_head		' increment the tx_head
tx_ret
		ret

'*******************************************
'
' Output a byte in hexval to the console
'
conout_hex_b
		mov	hexcnt, #2
		shl	hexval, #24
		jmp	#conout_hex

'*******************************************
'
' Output a word in hexval to the console
'
conout_hex_w
		mov	hexcnt, #4
		shl	hexval, #16
		jmp	#conout_hex

'*******************************************
'
' Output a long in hexval to the console
'
conout_hex_l
		mov	hexcnt, #8
conout_hex
		mov	data, hexval
		shr	data, #28
		cmp	data, #10	WZ, WC
	if_b	add	data, #48
	if_ae	add	data, #55
		call	#tx
		shl	hexval, #4
		djnz	hexcnt, #conout_hex
conout_hex_ret
conout_hex_l_ret
conout_hex_w_ret
conout_hex_b_ret
		ret

'*******************************************
'
' Output a carriage return to the console
'
conout_space
		mov	data, #32
		call	#tx
conout_space_ret
		ret

'*******************************************
'
' Output a carriage return to the console
'
conout_crlf
		mov	data, #13
		call	#tx
		mov	data, #10
		call	#tx
conout_crlf_ret
		ret

'*******************************************
'
' Output a string at strptr to the console
'
conout_string
		rdbyte	data, strptr	WZ
		add	strptr, #1
	if_z	jmp	#conout_string_ret
		call	#tx
		jmp	#conout_string
conout_string_ret
		ret

'*******************************************
'
' Output to the punch status - needed?
'
output_punstat
		mov	data, #0
		jmp	#command_0

'*******************************************
'
' Output to the punch. TODO: serial port 2?
'
output_pundata
		jmp	#command_0

'*******************************************
'
' Read i/o port to read from
'
input
		rdlong	port, io_port_ptr

		cmp	port, #constat WZ
	if_z	jmp	#input_constat
		cmp	port, #condata WZ
	if_z	jmp	#input_condata
		cmp	port, #punstat WZ
	if_z	jmp	#input_punstat
		cmp	port, #pundata WZ
	if_z	jmp	#input_pundata
		mov	data, #$00		' for now read $00 from all other ports
		wrlong	data, io_data_ptr
		jmp	#command_0

'*******************************************
'
' Read the console status
'
input_constat
		rdlong	t1, rx_head
		rdlong	t2, rx_tail
		cmp	t1, t2		WZ
	if_z	mov	data, #%00000010	' no data available
	if_nz	mov	data, #%00000011	' data is available
		wrlong	data, io_data_ptr
		jmp	#command_0

'*******************************************
'
' Read the console data
'
' returns 0 if no data is available
'
input_condata
		mov	data, #0		' no data available
		rdlong	t1, rx_head
		rdlong	t2, rx_tail
		cmp	t1, t2		WZ
	if_z	jmp	#:exit
		add	t2, rx_buffer
		rdbyte	data, t2
		sub	t2, rx_buffer
		add	t2, #1
		and	t2, #fdx_size-1
		wrlong	t2, rx_tail
:exit		wrlong	data, io_data_ptr	' store the input
		jmp	#command_0

'*******************************************
'
' Read the paper punch status
'
input_punstat
		mov	data, #%00000011	' always allow to output to punch
		jmp	#command_0

'*******************************************
'
' Read the paper punch data
'
' returns 0 if no data is available
'
input_pundata
		mov	data, #0		' no data available
		jmp	#command_0

'*******************************************
'
' Break - issued when the Z80 encounters
' a HALT instruction.
'
break
		rdlong	t1, io_port_ptr		' read the address of the register file
		mov	strptr, msg_break_ptr

		mov	t2, #8
:loop_r16	call	#conout_string
		rdword	hexval, t1		' read BC, DE, HL, AF, BC', DE', HL', AF'
		call	#conout_hex_w
		add	t1, #2
		djnz	t2, #:loop_r16

		add	t1, #8			' we are at R: skip over R, R2, IFF/IM, I, SP and PC

		call	#conout_string
		rdword	hexval, t1		' IX
		call	#conout_hex_w
		add	t1, #2

		call	#conout_string
		rdword	hexval, t1		' IY
		call	#conout_hex_w
		sub	t1, #2 + 4		' we are at IY: back to SP and PC

		call	#conout_string
		rdword	hexval, t1		' SP
		call	#conout_hex_w
		add	t1, #2

		call	#conout_string
		rdword	hexval, t1		' PC
		call	#conout_hex_w
		sub	t1, #6			' we are at PC: back to R register

		call	#conout_string
		rdbyte	hexval, t1		' R
		add	t1, #1
		rdbyte	t2, t1			' R2
		and	hexval, #%01111111	' R register's bit #7
		or	hexval, t2		' does never change from the last written value
		call	#conout_hex_b
		add	t1, #1

		call	#conout_string
		rdbyte	hexval, t1		' IFF1+2/IM
		mov	t2, t1			' save value
		and	hexval, #1		' IFF1 (interrupt flip-flop 1)
		call	#conout_hex_b

		call	#conout_string
		mov	hexval, t2		' IFF1+2/IM
		shr	hexval, #1		' shift bit #1 to #0
		and	hexval, #1		' IFF2 (interrupt flip-flop 2)
		call	#conout_hex_b

		call	#conout_string
		mov	hexval, t2		' IFF1+2/IM
		shr	hexval, #2		' shift bits #3..2 to #1..0
		and	hexval, #3		' IM (interrupt mode)
		call	#conout_hex_b
		add	t1, #1

		call	#conout_string
		rdbyte	hexval, t1		' I (interrupt vector register)
		call	#conout_hex_b

		call	#conout_crlf

		jmp	#command_0

'*******************************************
'
' Read a keyboard key and translate it
'
keyboard
		wrlong	t1, screen_ptr
		mov	t1, #0
		wrlong	t1, kbd_change

		mov	t1, kbd_lookup
		mov	t2, kbd_rows
		mov	t3, #64
		rdlong	kbd_data, t2
:loop
		rdbyte	kbd_index, t1		' get kbd_states entry to test
		mov	kbd_shift, kbd_index
		add	t1, #1
		shr	kbd_index, #3		' byte offset in LSB
		and	kbd_shift, #7		' shift for the interesting bit
		add	kbd_index, kbd_states	' from the kbd_states table
		rdbyte	data, kbd_index		' get status byte
		ror	data, kbd_shift		' rotate interesting bit to bit #0
		test	data, #1	WC	' is the state set?
		rcr	kbd_data, #1
		sub	t3, #1
		test	t3, #31			' completed four rows?
	if_z	wrlong	kbd_data, t2
	if_z	add	t2, #4
	if_z	rdlong	kbd_data, t2
		tjnz	t3, :loop
		wrlong	kbd_data, t2

		jmp	#command

'*******************************************
'
' Read the TRS-80 keyboard matrix
' Address is in io_port, address bits 0..7
' determine the keyboard row(s) to read
'
key_matrix
		mov	t1, #0
		mov	t2, kbd_rows
		mov	t3, #8
		mov	data, #$01
:loop		test	port, data		WZ
		rdbyte	kbd_data, t2
	if_nz	or	t1, kbd_data
		add	t2, #1
		shl	data, #1
		djnz	t3, #:loop
		wrbyte	t1, io_data_ptr
		jmp	#command_0

		fit	$1f0

'***************************************************************************
'*   w/o SHIFT                             with SHIFT
'*   +-------------------------------+     +-------------------------------+
'*   | 0   1   2   3   4   5   6   7 |     | 0   1   2   3   4   5   6   7 |
'*+--+---+---+---+---+---+---+---+---+  +--+---+---+---+---+---+---+---+---+
'*|0 | @ | A | B | C | D | E | F | G |  |0 | ` | a | b | c | d | e | f | g |
'*|  +---+---+---+---+---+---+---+---+  |  +---+---+---+---+---+---+---+---+
'*|1 | H | I | J | K | L | M | N | O |  |1 | h | i | j | k | l | m | n | o |
'*|  +---+---+---+---+---+---+---+---+  |  +---+---+---+---+---+---+---+---+
'*|2 | P | Q | R | S | T | U | V | W |  |2 | p | q | r | s | t | u | v | w |
'*|  +---+---+---+---+---+---+---+---+  |  +---+---+---+---+---+---+---+---+
'*|3 | X | Y | Z | [ | \ | ] | ^ | _ |  |3 | x | y | z | { | | | } | ~ |   |
'*|  +---+---+---+---+---+---+---+---+  |  +---+---+---+---+---+---+---+---+
'*|4 | 0 | 1 | 2 | 3 | 4 | 5 | 6 | 7 |  |4 |   | ! | " | # | $ | % | & | ' |
'*|  +---+---+---+---+---+---+---+---+  |  +---+---+---+---+---+---+---+---+
'*|5 | 8 | 9 | : | ; | , | - | . | / |  |5 | ( | ) | * | + | < | = | > | ? |
'*|  +---+---+---+---+---+---+---+---+  |  +---+---+---+---+---+---+---+---+
'*|6 |ENT|CLR|BRK|UP |DN |LFT|RGT|SPC|  |6 |ENT|CLR|BRK|UP |DN |LFT|RGT|SPC|
'*|  +---+---+---+---+---+---+---+---+  |  +---+---+---+---+---+---+---+---+
'*|7 |SHF|ALT|PUP|PDN|INS|DEL|CTL|END|  |7 |SHF|ALT|PUP|PDN|INS|DEL|CTL|END|
'*+--+---+---+---+---+---+---+---+---+  +--+---+---+---+---+---+---+---+---+
'***************************************************************************

kbd_lookup_table
	byte	$40,$41,$42,$43,$44,$45,$46,$47
	byte	$48,$49,$4a,$4b,$4c,$4d,$4e,$4f
	byte	$50,$51,$51,$53,$54,$55,$56,$57
	byte	$58,$59,$5a,$5b,$5c,$5d,$5e,$5f
	byte	$30,$31,$32,$33,$34,$35,$36,$37
	byte	$38,$39,$3a,$3b,$3c,$3d,$3e,$3f
	byte	$0d,$c4,$cb,$c2,$c3,$c0,$c1,$20
	byte	$f0,$f4,$c6,$c7,$ca,$c9,$f2,$c5

kbd_rows_table
	long	0, 0, 0, 0, 0, 0, 0, 0


''	09	Tab
''	0D	Enter
''	20	Space
''	21	!
''	22	"
''	23	#
''	24	$
''	25	%
''	26	&
''	27	'
''	28	(
''	29	)
''	2A	*
''	2B	+
''	2C	,
''	2D	-
''	2E	.
''	2F	/
''	30	0..9
''	3A	:
''	3B	;
''	3C	<
''	3D	=
''	3E	>
''	3F	?
''	40	@	
''	41..5A	A..Z
''	5B	[
''	5C	\
''	5D	]
''	5E	^
''	5F	_
''	60	`
''	61..7A	a..z
''	7B	{
''	7C	|
''	7D	}
''	7E	~

''	80-BF	(future international character support)

''	C0	Left Arrow
''	C1	Right Arrow
''	C2	Up Arrow
''	C3	Down Arrow
''	C4	Home
''	C5	End
''	C6	Page Up
''	C7	Page Down
''	C8	Backspace
''	C9	Delete
''	CA	Insert
''	CB	Esc
''	CC	Apps
''	CD	Power
''	CE	Sleep
''	CF	Wakeup

''	D0..DB	F1..F12
''	DC	Print Screen
''	DD	Scroll Lock
''	DE	Caps Lock
''	DF	Num Lock

''	E0..E9	Keypad 0..9
''	EA	Keypad .
''	EB	Keypad Enter
''	EC	Keypad +
''	ED	Keypad -
''	EE	Keypad *
''	EF	Keypad /

''	F0	Left Shift
''	F1	Right Shift
''	F2	Left Ctrl
''	F3	Right Ctrl
''	F4	Left Alt
''	F5	Right Alt
''	F6	Left Win
''	F7	Right Win

''	FD	Scroll Lock State
''	FE	Caps Lock State
''	FF	Num Lock State


msg_break	byte	"BC:",0
		byte	" DE:",0
		byte	" HL:",0
		byte	" AF:",0
		byte	" BC'",0
		byte	" DE'",0
		byte	" HL'",0
		byte	" AF'",0
		byte	13,10,"IX:",0
		byte	" IY:",0
		byte	" SP:",0
		byte	" PC:",0
		byte	" R:",0
		byte	" IFF1:",0
		byte	" IFF2:",0
		byte	" IM:",0
		byte	" I:",0

