'******************************************************************************
'*  trs80_video.spin - Output a 12 scanline bitmap
'*
'*  This is based on ideas and code from Debug_1pinTV by "Cluso99"
'*
'*  (c) Juergen Buchmueller <pullmoll@t-online.de>
'*
'* $Id: yaz80_demo.spin,v 1.8 2010-03-21 12:43:11 pm Exp $
'******************************************************************************
CON

	tvPin		=	18
#define PAL

#ifdef NTSC
'' NTSC 64x16
ocols			=	64			' number of columns
orows			=	16*12/8			' number of rows
ocolsfrq		=	22_478			' Hz per active pixel
oequal1			=	6			' number of equalization pulses
oserr			=	6			' number of serration pulses
oequal2			=	6			' number of equalization pulses
oblank1			=	36			' number of blank lines
oactive			=	16*12			' number of active lines
oblank2			=	25			' number of blank lines
otsync			=	39			' temp sync pulse
ohalf			=	4370			' vscl half line
obackp			=	4171	 		' vscl back porch (sync to active)
ofrontp			=	4145			' vscl front porch (active to sync)
oequal			=	4116			' vscl equalization pulse (sync/2)
osync			=	4136			' vscl sync pulse
osynch			=	4330			' vscl half-sync
oequalh			=	4350			' vscl half-equal
ovsclch			=	4102			' vscl character
ictra			=	12			' CTRA with PLLdiv
ifrqa			=	231701456		' required FRQA value (5MHz*16) (xfrqa replaced by start routine)
ifrqb			=	$4924_0000		' 40/140 << 32 = 1,227,096,064

ifrqa_80MHz		=	231701456		' required FRQA value (5MHz*16)
ifrqa_96MHz		=	257446064		' required FRQA value (6MHz*16)
ifrqa_100MHz		=	247148224		' required FRQA value (6.25MHz*16)
ifrqa_104MHz		=	237642512		' required FRQA value (6.5MHz*16)
ifrqa_108MHz		=	228840944		' required FRQA value (13.5MHz*8)
#endif

'--------------------------------------------------------------------------------------------------
#ifdef PAL
'' PAL	64x16 at 6x12px == 48x24 at 8x8px
ocols			=	64			' number of columns
orows			=	16*12/8			' number of rows
ocolsfrq		=	22_321			' Hz per active pixel
oequal1			=	4			' number of equalization pulses
oserr			=	5			' number of serration pulses
oequal2			=	5			' number of equalization pulses
oblank1			=	63			' number of blank lines
oactive			=	192			' number of active lines
oblank2			=	49			' number of blank lines
otsync			=	39			' temp sync pulse 
ohalf			=	4369			' vscl half line
obackp			=	4176			' vscl back porch (sync to active)
ofrontp			=	4139			' vscl front porch (active to sync)
oequal			=	4115			' vscl equalization pulse (sync/2)
osync			=	4135			' vscl sync pulse
osynch			=	4330			' vscl half-sync
oequalh			=	4350			' vscl half-equal
ovsclch			=	4102			' vscl character
ictra			=	12			' CTRA with PLLdiv
ifrqa			=	230083104		' required FRQA value (5MHz*16) (xfrqa replaced by start routine)
ifrqb			=	$4924_0000		' 40/140 << 32 = 1,227,096,064

ifrqa_80MHz		=	230083104		' required FRQA value (5MHz*16)
ifrqa_96MHz		=	191735920		' required FRQA value (6MHz*16)
ifrqa_100MHz		=	184066480		' required FRQA value (6.25MHz*16)
ifrqa_104MHz		=	176987008		' required FRQA value (6.5MHz*16)
ifrqa_108MHz		=	170431936		' required FRQA value (13.5MHz*8)
#endif
'--------------------------------------------------------------------------------------------------

VAR
	long	cog
	long	i

PUB start : okay
' bitmap is the address of the bitmap buffer * 32 + the tvPin number

	stop
	Setforxtalfreq					'set ifrqa in hub for the current clkfreq before cognew 
	repeat i from 0 to 1023
		videoram[i] := i & 255
	pin_no := tvPin
	okay := cog := COGNEW(@entry, 0) + 1

PUB stop
	if cog
		COGSTOP(cog - 1)
		cog := 0

PRI Setforxtalfreq
'' Set the frqa value depending on the actual clkfreq
	Case clkfreq
		 80_000_000: xfrqa := ifrqa_80MHz	' 5.00 MHz
		 96_000_000: xfrqa := ifrqa_96MHz	' 6.00 MHz
		100_000_000: xfrqa := ifrqa_100MHz	' 6.25 MHz
		104_000_000: xfrqa := ifrqa_104MHz	' 6.50 MHz
		108_000_000: xfrqa := ifrqa_108MHz	'13.50 MHz

DAT
		org	0
entry
		mov	FRQB, xfrqb			' default = 40/140

		movi	CTRA, #ictra
		mov	FRQA, xfrqa

		movs	CTRB, pin_no			' set pin
		mov	count, #1
		shl	count, pin_no
		mov	DIRA, count			' set pin mask
		mov	count, pin_no
		shr	count, #3
		movd	VCFG, count			' set VGroup
		mov	count, #1
		and	pin_no, #7
		shl	count, pin_no
		movs	VCFG, count			' set VPins
		movi	VCFG, #%0_01_0_0_0_000		' VGA mode, 1 bit per pixel

'**************************************************************************************************
frame		add	framectr, #1			' inc frame counter
		mov	rows, #oequal1
:equalizing1
		mov	vscl, xequal			' equalizing pulse (short)
		waitvid xFF00, #0
		movi	CTRB, #0			' turn off blank
		mov	vscl, xequalh			' equalizing pulse (long)
		waitvid xFF00, #0
		movi	CTRB, #%0_00110_000		' turn on blank
		djnz	rows, #:equalizing1
'--------------------------------------------------------------------------------------------------
		mov	rows, #oserr			' serration pulses
:serration
		mov	vscl, xsynch			' serration pulse (long)
		waitvid xFF00, #0		
		movi	CTRB, #0			' turn off blank
		mov	vscl, xsync			' serration pulse (short)
		waitvid xFF00, #0
		movi	CTRB, #%0_00110_000		' turn on blank
		djnz	rows, #:serration
'--------------------------------------------------------------------------------------------------
		mov	rows, #oequal2
:equalizing2
		mov	vscl, xequal			' equalizing pulse (short)
		waitvid xFF00, #0
		movi	CTRB, #0			' turn off blank
		mov	vscl, xequalh			' equalizing pulse (long)
		waitvid xFF00, #0
		movi	CTRB, #%0_00110_000		' turn on blank
		djnz	rows, #:equalizing2
'==================================================================================================
		mov	rows, #oblank1
:doblank1
		mov	vscl, xsync			' 4.7uSec @ -40 IRE
		waitvid xFF00, #0
		movi	CTRB, #0			' turn off blank
		mov	vscl, xsynch			' blank line
		waitvid xFF00, #0
		movi	CTRB, #%0_00110_000		' turn on blank
		mov	vscl, xhalf			' half line ???
		waitvid xFF00, #0
		djnz	rows, #:doblank1
'==================================================================================================
'display active lines
		mov	fontindex, font_ptr
		mov	scrptr0, screen_ptr		' initialize bitmap pointer
		mov	rows, #oactive
doactive
		mov	vscl, xsync			' 4.7uSec @ -40 IRE
		waitvid xFF00, #0
		movi	CTRB, #0			' turn off blank
		mov	vscl, xbackp			' back porch
		waitvid xFF00, #0
		movi	CTRB, #%0_00110_000		' turn on blank
		mov	vscl, xvsclch			' 1 PLLA per pixel, 6 PLLA per frame
		mov	count, #ocols			' longs per line
		mov	scrptr, scrptr0
'--------------------------------------------------------------------------------------------------
'display entire pixel line from bmapptr..
:active
		rdbyte	ch, scrptr
		shl	ch, #2
		add	ch, fontindex
		rdlong	bits, ch
		ror	bits, fontshift
		waitvid	xFF00, bits			' output to screen
		add	scrptr, #1
		djnz	count, #:active			' do entire line
'--------------------------------------------------------------------------------------------------

		add	fontshift, #8
		and	fontshift, #3*8		WZ
	if_z	add	fontindex, x400
	if_z	cmp	fontindex, font_end
	if_z	mov	fontindex, font_ptr
	if_z	add	scrptr0, #ocols

		mov	vscl, xfrontp			' front porch
		waitvid xFF00, #0			' output blank
		djnz	rows, #doactive			' next row
'==================================================================================================
		mov	rows, #oblank2
:doblank2
		mov	vscl, xsync			' 4.7uSec @ -40 IRE
		waitvid xFF00, #0
		movi	CTRB, #0			' turn off blank
		mov	vscl, xsynch			' blank line
		waitvid xFF00, #0
		movi	CTRB, #%0_00110_000		' turn on blank
		mov	vscl, xhalf			' half line ???
		waitvid xFF00, #0
		djnz	rows, #:doblank2
'==================================================================================================
		jmp	#frame
'**************************************************************************************************
'--------------------------------------------------------------------------------------------------
'constants > $1FF
xhalf		long	ohalf
xbackp		long	obackp
xfrontp		long	ofrontp
xequal		long	oequal
xsync		long	osync
xsynch		long	osynch
xequalh		long	oequalh
xvsclch		long	ovsclch
xfrqa		long	ifrqa
xfrqb		long	ifrqb

xFF00		long	$FF00			' white / black
x400		long	$400
font_ptr	long	@@@font
font_end	long	@@@font + $c00
screen_ptr	long	@@@videoram
pin_no		long	0-0

ch2		long	0
ch		long	0
bits		long	0			' current character / character bitmap
fontindex	long	0
fontshift	long	0
scrptr0		long	0			' pointer to screen data per character row
scrptr		long	0			' pointer to screen data per scanline
framectr	long	0
count		long	0			' all purpose counter
rows		long	0			' row counter
t1		long	0

		fit	$1f0
videoram	byte	0[64*16]

font				' chr($00)
		byte	$00	' ........
		byte	$3e	' .#####..
		byte	$22	' .#...#..
		byte	$22	' .#...#..

				' chr($01)
		byte	$00	' ........
		byte	$3e	' .#####..
		byte	$02	' .#......
		byte	$02	' .#......

				' chr($02)
		byte	$00	' ........
		byte	$08	' ...#....
		byte	$08	' ...#....
		byte	$08	' ...#....

				' chr($03)
		byte	$00	' ........
		byte	$20	' .....#..
		byte	$20	' .....#..
		byte	$20	' .....#..

				' chr($04)
		byte	$00	' ........
		byte	$04	' ..#.....
		byte	$08	' ...#....
		byte	$10	' ....#...

				' chr($05)
		byte	$00	' ........
		byte	$3e	' .#####..
		byte	$22	' .#...#..
		byte	$36	' .##.##..

				' chr($06)
		byte	$00	' ........
		byte	$00	' ........
		byte	$20	' .....#..
		byte	$10	' ....#...

				' chr($07)
		byte	$00	' ........
		byte	$1c	' ..###...
		byte	$22	' .#...#..
		byte	$22	' .#...#..

				' chr($08)
		byte	$00	' ........
		byte	$08	' ...#....
		byte	$04	' ..#.....
		byte	$1e	' .####...

				' chr($09)
		byte	$00	' ........
		byte	$00	' ........
		byte	$08	' ...#....
		byte	$10	' ....#...

				' chr($0a)
		byte	$00	' ........
		byte	$3e	' .#####..
		byte	$00	' ........
		byte	$00	' ........

				' chr($0b)
		byte	$00	' ........
		byte	$00	' ........
		byte	$08	' ...#....
		byte	$08	' ...#....

				' chr($0c)
		byte	$00	' ........
		byte	$08	' ...#....
		byte	$2a	' .#.#.#..
		byte	$1c	' ..###...

				' chr($0d)
		byte	$00	' ........
		byte	$00	' ........
		byte	$08	' ...#....
		byte	$04	' ..#.....

				' chr($0e)
		byte	$00	' ........
		byte	$1c	' ..###...
		byte	$22	' .#...#..
		byte	$36	' .##.##..

				' chr($0f)
		byte	$00	' ........
		byte	$1c	' ..###...
		byte	$22	' .#...#..
		byte	$22	' .#...#..

				' chr($10)
		byte	$00	' ........
		byte	$3e	' .#####..
		byte	$22	' .#...#..
		byte	$22	' .#...#..

				' chr($11)
		byte	$00	' ........
		byte	$1c	' ..###...
		byte	$2a	' .#.#.#..
		byte	$2a	' .#.#.#..

				' chr($12)
		byte	$00	' ........
		byte	$1c	' ..###...
		byte	$22	' .#...#..
		byte	$22	' .#...#..

				' chr($13)
		byte	$00	' ........
		byte	$1c	' ..###...
		byte	$22	' .#...#..
		byte	$22	' .#...#..

				' chr($14)
		byte	$00	' ........
		byte	$1c	' ..###...
		byte	$2a	' .#.#.#..
		byte	$2a	' .#.#.#..

				' chr($15)
		byte	$00	' ........
		byte	$00	' ........
		byte	$28	' ...#.#..
		byte	$10	' ....#...

				' chr($16)
		byte	$00	' ........
		byte	$1c	' ..###...
		byte	$14	' ..#.#...
		byte	$14	' ..#.#...

				' chr($17)
		byte	$00	' ........
		byte	$20	' .....#..
		byte	$20	' .....#..
		byte	$20	' .....#..

				' chr($18)
		byte	$00	' ........
		byte	$3e	' .#####..
		byte	$22	' .#...#..
		byte	$14	' ..#.#...

				' chr($19)
		byte	$00	' ........
		byte	$08	' ...#....
		byte	$08	' ...#....
		byte	$1c	' ..###...

				' chr($1a)
		byte	$00	' ........
		byte	$1c	' ..###...
		byte	$22	' .#...#..
		byte	$02	' .#......

				' chr($1b)
		byte	$00	' ........
		byte	$1c	' ..###...
		byte	$22	' .#...#..
		byte	$22	' .#...#..

				' chr($1c)
		byte	$00	' ........
		byte	$3e	' .#####..
		byte	$2a	' .#.#.#..
		byte	$2a	' .#.#.#..

				' chr($1d)
		byte	$00	' ........
		byte	$3e	' .#####..
		byte	$22	' .#...#..
		byte	$22	' .#...#..

				' chr($1e)
		byte	$00	' ........
		byte	$3e	' .#####..
		byte	$22	' .#...#..
		byte	$22	' .#...#..

				' chr($1f)
		byte	$00	' ........
		byte	$3e	' .#####..
		byte	$2a	' .#.#.#..
		byte	$2a	' .#.#.#..

				' chr($20)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($21)
		byte	$00	' ........
		byte	$08	' ...#....
		byte	$08	' ...#....
		byte	$08	' ...#....

				' chr($22)
		byte	$00	' ........
		byte	$14	' ..#.#...
		byte	$14	' ..#.#...
		byte	$14	' ..#.#...

				' chr($23)
		byte	$00	' ........
		byte	$14	' ..#.#...
		byte	$14	' ..#.#...
		byte	$3e	' .#####..

				' chr($24)
		byte	$00	' ........
		byte	$08	' ...#....
		byte	$3c	' ..####..
		byte	$0a	' .#.#....

				' chr($25)
		byte	$00	' ........
		byte	$06	' .##.....
		byte	$26	' .##..#..
		byte	$10	' ....#...

				' chr($26)
		byte	$00	' ........
		byte	$04	' ..#.....
		byte	$0a	' .#.#....
		byte	$0a	' .#.#....

				' chr($27)
		byte	$00	' ........
		byte	$0c	' ..##....
		byte	$0c	' ..##....
		byte	$04	' ..#.....

				' chr($28)
		byte	$00	' ........
		byte	$10	' ....#...
		byte	$08	' ...#....
		byte	$04	' ..#.....

				' chr($29)
		byte	$00	' ........
		byte	$04	' ..#.....
		byte	$08	' ...#....
		byte	$10	' ....#...

				' chr($2a)
		byte	$00	' ........
		byte	$08	' ...#....
		byte	$2a	' .#.#.#..
		byte	$1c	' ..###...

				' chr($2b)
		byte	$00	' ........
		byte	$00	' ........
		byte	$08	' ...#....
		byte	$08	' ...#....

				' chr($2c)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($2d)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($2e)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($2f)
		byte	$00	' ........
		byte	$00	' ........
		byte	$20	' .....#..
		byte	$10	' ....#...

				' chr($30)
		byte	$00	' ........
		byte	$1c	' ..###...
		byte	$22	' .#...#..
		byte	$32	' .#..##..

				' chr($31)
		byte	$00	' ........
		byte	$08	' ...#....
		byte	$0c	' ..##....
		byte	$08	' ...#....

				' chr($32)
		byte	$00	' ........
		byte	$1c	' ..###...
		byte	$22	' .#...#..
		byte	$20	' .....#..

				' chr($33)
		byte	$00	' ........
		byte	$1c	' ..###...
		byte	$22	' .#...#..
		byte	$20	' .....#..

				' chr($34)
		byte	$00	' ........
		byte	$10	' ....#...
		byte	$18	' ...##...
		byte	$14	' ..#.#...

				' chr($35)
		byte	$00	' ........
		byte	$3e	' .#####..
		byte	$02	' .#......
		byte	$1e	' .####...

				' chr($36)
		byte	$00	' ........
		byte	$18	' ...##...
		byte	$04	' ..#.....
		byte	$02	' .#......

				' chr($37)
		byte	$00	' ........
		byte	$3e	' .#####..
		byte	$20	' .....#..
		byte	$10	' ....#...

				' chr($38)
		byte	$00	' ........
		byte	$1c	' ..###...
		byte	$22	' .#...#..
		byte	$22	' .#...#..

				' chr($39)
		byte	$00	' ........
		byte	$1c	' ..###...
		byte	$22	' .#...#..
		byte	$22	' .#...#..

				' chr($3a)
		byte	$00	' ........
		byte	$00	' ........
		byte	$0c	' ..##....
		byte	$0c	' ..##....

				' chr($3b)
		byte	$00	' ........
		byte	$0c	' ..##....
		byte	$0c	' ..##....
		byte	$00	' ........

				' chr($3c)
		byte	$00	' ........
		byte	$10	' ....#...
		byte	$08	' ...#....
		byte	$04	' ..#.....

				' chr($3d)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$3e	' .#####..

				' chr($3e)
		byte	$00	' ........
		byte	$04	' ..#.....
		byte	$08	' ...#....
		byte	$10	' ....#...

				' chr($3f)
		byte	$00	' ........
		byte	$1c	' ..###...
		byte	$22	' .#...#..
		byte	$20	' .....#..

				' chr($40)
		byte	$00	' ........
		byte	$1c	' ..###...
		byte	$22	' .#...#..
		byte	$20	' .....#..

				' chr($41)
		byte	$00	' ........
		byte	$08	' ...#....
		byte	$14	' ..#.#...
		byte	$22	' .#...#..

				' chr($42)
		byte	$00	' ........
		byte	$1e	' .####...
		byte	$24	' ..#..#..
		byte	$24	' ..#..#..

				' chr($43)
		byte	$00	' ........
		byte	$1c	' ..###...
		byte	$22	' .#...#..
		byte	$02	' .#......

				' chr($44)
		byte	$00	' ........
		byte	$1e	' .####...
		byte	$24	' ..#..#..
		byte	$24	' ..#..#..

				' chr($45)
		byte	$00	' ........
		byte	$3e	' .#####..
		byte	$02	' .#......
		byte	$02	' .#......

				' chr($46)
		byte	$00	' ........
		byte	$3e	' .#####..
		byte	$02	' .#......
		byte	$02	' .#......

				' chr($47)
		byte	$00	' ........
		byte	$3c	' ..####..
		byte	$02	' .#......
		byte	$02	' .#......

				' chr($48)
		byte	$00	' ........
		byte	$22	' .#...#..
		byte	$22	' .#...#..
		byte	$22	' .#...#..

				' chr($49)
		byte	$00	' ........
		byte	$1c	' ..###...
		byte	$08	' ...#....
		byte	$08	' ...#....

				' chr($4a)
		byte	$00	' ........
		byte	$20	' .....#..
		byte	$20	' .....#..
		byte	$20	' .....#..

				' chr($4b)
		byte	$00	' ........
		byte	$22	' .#...#..
		byte	$12	' .#..#...
		byte	$0a	' .#.#....

				' chr($4c)
		byte	$00	' ........
		byte	$02	' .#......
		byte	$02	' .#......
		byte	$02	' .#......

				' chr($4d)
		byte	$00	' ........
		byte	$22	' .#...#..
		byte	$36	' .##.##..
		byte	$2a	' .#.#.#..

				' chr($4e)
		byte	$00	' ........
		byte	$22	' .#...#..
		byte	$26	' .##..#..
		byte	$2a	' .#.#.#..

				' chr($4f)
		byte	$00	' ........
		byte	$1c	' ..###...
		byte	$22	' .#...#..
		byte	$22	' .#...#..

				' chr($50)
		byte	$00	' ........
		byte	$1e	' .####...
		byte	$22	' .#...#..
		byte	$22	' .#...#..

				' chr($51)
		byte	$00	' ........
		byte	$1c	' ..###...
		byte	$22	' .#...#..
		byte	$22	' .#...#..

				' chr($52)
		byte	$00	' ........
		byte	$1e	' .####...
		byte	$22	' .#...#..
		byte	$22	' .#...#..

				' chr($53)
		byte	$00	' ........
		byte	$1c	' ..###...
		byte	$22	' .#...#..
		byte	$02	' .#......

				' chr($54)
		byte	$00	' ........
		byte	$3e	' .#####..
		byte	$08	' ...#....
		byte	$08	' ...#....

				' chr($55)
		byte	$00	' ........
		byte	$22	' .#...#..
		byte	$22	' .#...#..
		byte	$22	' .#...#..

				' chr($56)
		byte	$00	' ........
		byte	$22	' .#...#..
		byte	$22	' .#...#..
		byte	$22	' .#...#..

				' chr($57)
		byte	$00	' ........
		byte	$22	' .#...#..
		byte	$22	' .#...#..
		byte	$22	' .#...#..

				' chr($58)
		byte	$00	' ........
		byte	$22	' .#...#..
		byte	$22	' .#...#..
		byte	$14	' ..#.#...

				' chr($59)
		byte	$00	' ........
		byte	$22	' .#...#..
		byte	$22	' .#...#..
		byte	$14	' ..#.#...

				' chr($5a)
		byte	$00	' ........
		byte	$3e	' .#####..
		byte	$20	' .....#..
		byte	$10	' ....#...

				' chr($5b)
		byte	$00	' ........
		byte	$08	' ...#....
		byte	$1c	' ..###...
		byte	$2a	' .#.#.#..

				' chr($5c)
		byte	$00	' ........
		byte	$08	' ...#....
		byte	$08	' ...#....
		byte	$08	' ...#....

				' chr($5d)
		byte	$00	' ........
		byte	$00	' ........
		byte	$08	' ...#....
		byte	$04	' ..#.....

				' chr($5e)
		byte	$00	' ........
		byte	$00	' ........
		byte	$08	' ...#....
		byte	$10	' ....#...

				' chr($5f)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($60)
		byte	$00	' ........
		byte	$18	' ...##...
		byte	$18	' ...##...
		byte	$08	' ...#....

				' chr($61)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$1c	' ..###...

				' chr($62)
		byte	$00	' ........
		byte	$02	' .#......
		byte	$02	' .#......
		byte	$1a	' .#.##...

				' chr($63)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$1c	' ..###...

				' chr($64)
		byte	$00	' ........
		byte	$20	' .....#..
		byte	$20	' .....#..
		byte	$2c	' ..##.#..

				' chr($65)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$1c	' ..###...

				' chr($66)
		byte	$00	' ........
		byte	$10	' ....#...
		byte	$28	' ...#.#..
		byte	$08	' ...#....

				' chr($67)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$2c	' ..##.#..

				' chr($68)
		byte	$00	' ........
		byte	$02	' .#......
		byte	$02	' .#......
		byte	$1a	' .#.##...

				' chr($69)
		byte	$00	' ........
		byte	$08	' ...#....
		byte	$00	' ........
		byte	$0c	' ..##....

				' chr($6a)
		byte	$00	' ........
		byte	$20	' .....#..
		byte	$00	' ........
		byte	$20	' .....#..

				' chr($6b)
		byte	$00	' ........
		byte	$02	' .#......
		byte	$02	' .#......
		byte	$12	' .#..#...

				' chr($6c)
		byte	$00	' ........
		byte	$0c	' ..##....
		byte	$08	' ...#....
		byte	$08	' ...#....

				' chr($6d)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$16	' .##.#...

				' chr($6e)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$1a	' .#.##...

				' chr($6f)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$1c	' ..###...

				' chr($70)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$1a	' .#.##...

				' chr($71)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$2c	' ..##.#..

				' chr($72)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$1a	' .#.##...

				' chr($73)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$3c	' ..####..

				' chr($74)
		byte	$00	' ........
		byte	$08	' ...#....
		byte	$08	' ...#....
		byte	$3e	' .#####..

				' chr($75)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$22	' .#...#..

				' chr($76)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$22	' .#...#..

				' chr($77)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$22	' .#...#..

				' chr($78)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$22	' .#...#..

				' chr($79)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$22	' .#...#..

				' chr($7a)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$3e	' .#####..

				' chr($7b)
		byte	$00	' ........
		byte	$10	' ....#...
		byte	$08	' ...#....
		byte	$08	' ...#....

				' chr($7c)
		byte	$00	' ........
		byte	$08	' ...#....
		byte	$08	' ...#....
		byte	$08	' ...#....

				' chr($7d)
		byte	$00	' ........
		byte	$04	' ..#.....
		byte	$08	' ...#....
		byte	$08	' ...#....

				' chr($7e)
		byte	$00	' ........
		byte	$04	' ..#.....
		byte	$2a	' .#.#.#..
		byte	$10	' ....#...

				' chr($7f)
		byte	$00	' ........
		byte	$14	' ..#.#...
		byte	$2a	' .#.#.#..
		byte	$14	' ..#.#...

				' chr($80)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($81)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($82)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($83)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($84)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($85)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($86)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($87)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($88)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($89)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($8a)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($8b)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($8c)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($8d)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($8e)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($8f)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($90)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($91)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($92)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($93)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($94)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($95)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($96)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($97)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($98)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($99)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($9a)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($9b)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($9c)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($9d)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($9e)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($9f)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($a0)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($a1)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($a2)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($a3)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($a4)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($a5)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($a6)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($a7)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($a8)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($a9)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($aa)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($ab)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($ac)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($ad)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($ae)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($af)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($b0)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($b1)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($b2)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($b3)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($b4)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($b5)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($b6)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($b7)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($b8)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($b9)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($ba)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($bb)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($bc)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($bd)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($be)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($bf)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($c0)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($c1)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($c2)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($c3)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($c4)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($c5)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($c6)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($c7)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($c8)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($c9)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($ca)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($cb)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($cc)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($cd)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($ce)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($cf)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($d0)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($d1)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($d2)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($d3)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($d4)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($d5)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($d6)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($d7)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($d8)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($d9)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($da)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($db)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($dc)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($dd)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($de)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($df)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($e0)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($e1)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($e2)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($e3)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($e4)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($e5)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($e6)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($e7)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($e8)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($e9)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($ea)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($eb)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($ec)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($ed)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($ee)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($ef)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($f0)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($f1)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($f2)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($f3)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($f4)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($f5)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($f6)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($f7)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($f8)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($f9)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($fa)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($fb)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($fc)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($fd)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($fe)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($ff)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($00)
		byte	$22	' .#...#..
		byte	$22	' .#...#..
		byte	$22	' .#...#..
		byte	$3e	' .#####..

				' chr($01)
		byte	$02	' .#......
		byte	$02	' .#......
		byte	$02	' .#......
		byte	$02	' .#......

				' chr($02)
		byte	$08	' ...#....
		byte	$08	' ...#....
		byte	$08	' ...#....
		byte	$3e	' .#####..

				' chr($03)
		byte	$20	' .....#..
		byte	$20	' .....#..
		byte	$20	' .....#..
		byte	$3e	' .#####..

				' chr($04)
		byte	$3c	' ..####..
		byte	$08	' ...#....
		byte	$10	' ....#...
		byte	$20	' .....#..

				' chr($05)
		byte	$2a	' .#.#.#..
		byte	$36	' .##.##..
		byte	$22	' .#...#..
		byte	$3e	' .#####..

				' chr($06)
		byte	$0a	' .#.#....
		byte	$06	' .##.....
		byte	$02	' .#......
		byte	$00	' ........

				' chr($07)
		byte	$3e	' .#####..
		byte	$14	' ..#.#...
		byte	$14	' ..#.#...
		byte	$36	' .##.##..

				' chr($08)
		byte	$24	' ..#..#..
		byte	$28	' ...#.#..
		byte	$20	' .....#..
		byte	$20	' .....#..

				' chr($09)
		byte	$3e	' .#####..
		byte	$10	' ....#...
		byte	$08	' ...#....
		byte	$00	' ........

				' chr($0a)
		byte	$3e	' .#####..
		byte	$00	' ........
		byte	$00	' ........
		byte	$3e	' .#####..

				' chr($0b)
		byte	$2a	' .#.#.#..
		byte	$1c	' ..###...
		byte	$08	' ...#....
		byte	$00	' ........

				' chr($0c)
		byte	$08	' ...#....
		byte	$2a	' .#.#.#..
		byte	$1c	' ..###...
		byte	$08	' ...#....

				' chr($0d)
		byte	$3e	' .#####..
		byte	$04	' ..#.....
		byte	$08	' ...#....
		byte	$00	' ........

				' chr($0e)
		byte	$2a	' .#.#.#..
		byte	$36	' .##.##..
		byte	$22	' .#...#..
		byte	$1c	' ..###...

				' chr($0f)
		byte	$2a	' .#.#.#..
		byte	$22	' .#...#..
		byte	$22	' .#...#..
		byte	$1c	' ..###...

				' chr($10)
		byte	$3e	' .#####..
		byte	$22	' .#...#..
		byte	$22	' .#...#..
		byte	$3e	' .#####..

				' chr($11)
		byte	$3a	' .#.###..
		byte	$22	' .#...#..
		byte	$22	' .#...#..
		byte	$1c	' ..###...

				' chr($12)
		byte	$3a	' .#.###..
		byte	$2a	' .#.#.#..
		byte	$2a	' .#.#.#..
		byte	$1c	' ..###...

				' chr($13)
		byte	$2e	' .###.#..
		byte	$2a	' .#.#.#..
		byte	$2a	' .#.#.#..
		byte	$1c	' ..###...

				' chr($14)
		byte	$2e	' .###.#..
		byte	$22	' .#...#..
		byte	$22	' .#...#..
		byte	$1c	' ..###...

				' chr($15)
		byte	$2a	' .#.#.#..
		byte	$06	' .##.....
		byte	$02	' .#......
		byte	$00	' ........

				' chr($16)
		byte	$14	' ..#.#...
		byte	$14	' ..#.#...
		byte	$14	' ..#.#...
		byte	$36	' .##.##..

				' chr($17)
		byte	$3e	' .#####..
		byte	$20	' .....#..
		byte	$20	' .....#..
		byte	$20	' .....#..

				' chr($18)
		byte	$08	' ...#....
		byte	$14	' ..#.#...
		byte	$22	' .#...#..
		byte	$3e	' .#####..

				' chr($19)
		byte	$1c	' ..###...
		byte	$08	' ...#....
		byte	$08	' ...#....
		byte	$08	' ...#....

				' chr($1a)
		byte	$04	' ..#.....
		byte	$08	' ...#....
		byte	$00	' ........
		byte	$08	' ...#....

				' chr($1b)
		byte	$3e	' .#####..
		byte	$22	' .#...#..
		byte	$22	' .#...#..
		byte	$1c	' ..###...

				' chr($1c)
		byte	$2e	' .###.#..
		byte	$22	' .#...#..
		byte	$22	' .#...#..
		byte	$3e	' .#####..

				' chr($1d)
		byte	$2e	' .###.#..
		byte	$2a	' .#.#.#..
		byte	$2a	' .#.#.#..
		byte	$3e	' .#####..

				' chr($1e)
		byte	$3a	' .#.###..
		byte	$2a	' .#.#.#..
		byte	$2a	' .#.#.#..
		byte	$3e	' .#####..

				' chr($1f)
		byte	$3a	' .#.###..
		byte	$22	' .#...#..
		byte	$22	' .#...#..
		byte	$3e	' .#####..

				' chr($20)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($21)
		byte	$08	' ...#....
		byte	$08	' ...#....
		byte	$00	' ........
		byte	$08	' ...#....

				' chr($22)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($23)
		byte	$14	' ..#.#...
		byte	$3e	' .#####..
		byte	$14	' ..#.#...
		byte	$14	' ..#.#...

				' chr($24)
		byte	$1c	' ..###...
		byte	$28	' ...#.#..
		byte	$1e	' .####...
		byte	$08	' ...#....

				' chr($25)
		byte	$08	' ...#....
		byte	$04	' ..#.....
		byte	$32	' .#..##..
		byte	$30	' ....##..

				' chr($26)
		byte	$04	' ..#.....
		byte	$2a	' .#.#.#..
		byte	$12	' .#..#...
		byte	$2c	' ..##.#..

				' chr($27)
		byte	$02	' .#......
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($28)
		byte	$04	' ..#.....
		byte	$04	' ..#.....
		byte	$08	' ...#....
		byte	$10	' ....#...

				' chr($29)
		byte	$10	' ....#...
		byte	$10	' ....#...
		byte	$08	' ...#....
		byte	$04	' ..#.....

				' chr($2a)
		byte	$3e	' .#####..
		byte	$1c	' ..###...
		byte	$2a	' .#.#.#..
		byte	$08	' ...#....

				' chr($2b)
		byte	$3e	' .#####..
		byte	$08	' ...#....
		byte	$08	' ...#....
		byte	$00	' ........

				' chr($2c)
		byte	$00	' ........
		byte	$00	' ........
		byte	$0c	' ..##....
		byte	$0c	' ..##....

				' chr($2d)
		byte	$3e	' .#####..
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($2e)
		byte	$00	' ........
		byte	$00	' ........
		byte	$0c	' ..##....
		byte	$0c	' ..##....

				' chr($2f)
		byte	$08	' ...#....
		byte	$04	' ..#.....
		byte	$02	' .#......
		byte	$00	' ........

				' chr($30)
		byte	$2a	' .#.#.#..
		byte	$26	' .##..#..
		byte	$22	' .#...#..
		byte	$1c	' ..###...

				' chr($31)
		byte	$08	' ...#....
		byte	$08	' ...#....
		byte	$08	' ...#....
		byte	$1c	' ..###...

				' chr($32)
		byte	$1c	' ..###...
		byte	$02	' .#......
		byte	$02	' .#......
		byte	$3e	' .#####..

				' chr($33)
		byte	$18	' ...##...
		byte	$20	' .....#..
		byte	$22	' .#...#..
		byte	$1c	' ..###...

				' chr($34)
		byte	$12	' .#..#...
		byte	$3e	' .#####..
		byte	$10	' ....#...
		byte	$10	' ....#...

				' chr($35)
		byte	$20	' .....#..
		byte	$20	' .....#..
		byte	$22	' .#...#..
		byte	$1c	' ..###...

				' chr($36)
		byte	$1e	' .####...
		byte	$22	' .#...#..
		byte	$22	' .#...#..
		byte	$1c	' ..###...

				' chr($37)
		byte	$08	' ...#....
		byte	$04	' ..#.....
		byte	$02	' .#......
		byte	$02	' .#......

				' chr($38)
		byte	$1c	' ..###...
		byte	$22	' .#...#..
		byte	$22	' .#...#..
		byte	$1c	' ..###...

				' chr($39)
		byte	$3c	' ..####..
		byte	$20	' .....#..
		byte	$10	' ....#...
		byte	$0c	' ..##....

				' chr($3a)
		byte	$00	' ........
		byte	$0c	' ..##....
		byte	$0c	' ..##....
		byte	$00	' ........

				' chr($3b)
		byte	$0c	' ..##....
		byte	$0c	' ..##....
		byte	$04	' ..#.....
		byte	$02	' .#......

				' chr($3c)
		byte	$02	' .#......
		byte	$04	' ..#.....
		byte	$08	' ...#....
		byte	$10	' ....#...

				' chr($3d)
		byte	$00	' ........
		byte	$3e	' .#####..
		byte	$00	' ........
		byte	$00	' ........

				' chr($3e)
		byte	$20	' .....#..
		byte	$10	' ....#...
		byte	$08	' ...#....
		byte	$04	' ..#.....

				' chr($3f)
		byte	$10	' ....#...
		byte	$08	' ...#....
		byte	$00	' ........
		byte	$08	' ...#....

				' chr($40)
		byte	$2c	' ..##.#..
		byte	$2a	' .#.#.#..
		byte	$2a	' .#.#.#..
		byte	$1c	' ..###...

				' chr($41)
		byte	$22	' .#...#..
		byte	$3e	' .#####..
		byte	$22	' .#...#..
		byte	$22	' .#...#..

				' chr($42)
		byte	$1c	' ..###...
		byte	$24	' ..#..#..
		byte	$24	' ..#..#..
		byte	$1e	' .####...

				' chr($43)
		byte	$02	' .#......
		byte	$02	' .#......
		byte	$22	' .#...#..
		byte	$1c	' ..###...

				' chr($44)
		byte	$24	' ..#..#..
		byte	$24	' ..#..#..
		byte	$24	' ..#..#..
		byte	$1e	' .####...

				' chr($45)
		byte	$0e	' .###....
		byte	$02	' .#......
		byte	$02	' .#......
		byte	$3e	' .#####..

				' chr($46)
		byte	$0e	' .###....
		byte	$02	' .#......
		byte	$02	' .#......
		byte	$02	' .#......

				' chr($47)
		byte	$32	' .#..##..
		byte	$22	' .#...#..
		byte	$22	' .#...#..
		byte	$3c	' ..####..

				' chr($48)
		byte	$3e	' .#####..
		byte	$22	' .#...#..
		byte	$22	' .#...#..
		byte	$22	' .#...#..

				' chr($49)
		byte	$08	' ...#....
		byte	$08	' ...#....
		byte	$08	' ...#....
		byte	$1c	' ..###...

				' chr($4a)
		byte	$20	' .....#..
		byte	$20	' .....#..
		byte	$22	' .#...#..
		byte	$1c	' ..###...

				' chr($4b)
		byte	$06	' .##.....
		byte	$0a	' .#.#....
		byte	$12	' .#..#...
		byte	$22	' .#...#..

				' chr($4c)
		byte	$02	' .#......
		byte	$02	' .#......
		byte	$02	' .#......
		byte	$3e	' .#####..

				' chr($4d)
		byte	$2a	' .#.#.#..
		byte	$22	' .#...#..
		byte	$22	' .#...#..
		byte	$22	' .#...#..

				' chr($4e)
		byte	$32	' .#..##..
		byte	$22	' .#...#..
		byte	$22	' .#...#..
		byte	$22	' .#...#..

				' chr($4f)
		byte	$22	' .#...#..
		byte	$22	' .#...#..
		byte	$22	' .#...#..
		byte	$1c	' ..###...

				' chr($50)
		byte	$1e	' .####...
		byte	$02	' .#......
		byte	$02	' .#......
		byte	$02	' .#......

				' chr($51)
		byte	$22	' .#...#..
		byte	$2a	' .#.#.#..
		byte	$12	' .#..#...
		byte	$2c	' ..##.#..

				' chr($52)
		byte	$1e	' .####...
		byte	$0a	' .#.#....
		byte	$12	' .#..#...
		byte	$22	' .#...#..

				' chr($53)
		byte	$1c	' ..###...
		byte	$20	' .....#..
		byte	$22	' .#...#..
		byte	$1c	' ..###...

				' chr($54)
		byte	$08	' ...#....
		byte	$08	' ...#....
		byte	$08	' ...#....
		byte	$08	' ...#....

				' chr($55)
		byte	$22	' .#...#..
		byte	$22	' .#...#..
		byte	$22	' .#...#..
		byte	$1c	' ..###...

				' chr($56)
		byte	$14	' ..#.#...
		byte	$14	' ..#.#...
		byte	$08	' ...#....
		byte	$08	' ...#....

				' chr($57)
		byte	$22	' .#...#..
		byte	$2a	' .#.#.#..
		byte	$36	' .##.##..
		byte	$22	' .#...#..

				' chr($58)
		byte	$08	' ...#....
		byte	$14	' ..#.#...
		byte	$22	' .#...#..
		byte	$22	' .#...#..

				' chr($59)
		byte	$08	' ...#....
		byte	$08	' ...#....
		byte	$08	' ...#....
		byte	$08	' ...#....

				' chr($5a)
		byte	$08	' ...#....
		byte	$04	' ..#.....
		byte	$02	' .#......
		byte	$3e	' .#####..

				' chr($5b)
		byte	$08	' ...#....
		byte	$08	' ...#....
		byte	$08	' ...#....
		byte	$08	' ...#....

				' chr($5c)
		byte	$08	' ...#....
		byte	$2a	' .#.#.#..
		byte	$1c	' ..###...
		byte	$08	' ...#....

				' chr($5d)
		byte	$3e	' .#####..
		byte	$04	' ..#.....
		byte	$08	' ...#....
		byte	$00	' ........

				' chr($5e)
		byte	$3e	' .#####..
		byte	$10	' ....#...
		byte	$08	' ...#....
		byte	$00	' ........

				' chr($5f)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$3e	' .#####..

				' chr($60)
		byte	$10	' ....#...
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($61)
		byte	$20	' .....#..
		byte	$3c	' ..####..
		byte	$22	' .#...#..
		byte	$3c	' ..####..

				' chr($62)
		byte	$26	' .##..#..
		byte	$22	' .#...#..
		byte	$26	' .##..#..
		byte	$1a	' .#.##...

				' chr($63)
		byte	$22	' .#...#..
		byte	$02	' .#......
		byte	$22	' .#...#..
		byte	$1c	' ..###...

				' chr($64)
		byte	$32	' .#..##..
		byte	$22	' .#...#..
		byte	$32	' .#..##..
		byte	$2c	' ..##.#..

				' chr($65)
		byte	$22	' .#...#..
		byte	$3e	' .#####..
		byte	$02	' .#......
		byte	$1c	' ..###...

				' chr($66)
		byte	$1c	' ..###...
		byte	$08	' ...#....
		byte	$08	' ...#....
		byte	$08	' ...#....

				' chr($67)
		byte	$32	' .#..##..
		byte	$32	' .#..##..
		byte	$2c	' ..##.#..
		byte	$20	' .....#..

				' chr($68)
		byte	$26	' .##..#..
		byte	$22	' .#...#..
		byte	$22	' .#...#..
		byte	$22	' .#...#..

				' chr($69)
		byte	$08	' ...#....
		byte	$08	' ...#....
		byte	$08	' ...#....
		byte	$1c	' ..###...

				' chr($6a)
		byte	$20	' .....#..
		byte	$20	' .....#..
		byte	$22	' .#...#..
		byte	$1c	' ..###...

				' chr($6b)
		byte	$0a	' .#.#....
		byte	$06	' .##.....
		byte	$0a	' .#.#....
		byte	$12	' .#..#...

				' chr($6c)
		byte	$08	' ...#....
		byte	$08	' ...#....
		byte	$08	' ...#....
		byte	$1c	' ..###...

				' chr($6d)
		byte	$2a	' .#.#.#..
		byte	$2a	' .#.#.#..
		byte	$2a	' .#.#.#..
		byte	$2a	' .#.#.#..

				' chr($6e)
		byte	$26	' .##..#..
		byte	$22	' .#...#..
		byte	$22	' .#...#..
		byte	$22	' .#...#..

				' chr($6f)
		byte	$22	' .#...#..
		byte	$22	' .#...#..
		byte	$22	' .#...#..
		byte	$1c	' ..###...

				' chr($70)
		byte	$26	' .##..#..
		byte	$22	' .#...#..
		byte	$26	' .##..#..
		byte	$1a	' .#.##...

				' chr($71)
		byte	$32	' .#..##..
		byte	$22	' .#...#..
		byte	$32	' .#..##..
		byte	$2c	' ..##.#..

				' chr($72)
		byte	$26	' .##..#..
		byte	$02	' .#......
		byte	$02	' .#......
		byte	$02	' .#......

				' chr($73)
		byte	$02	' .#......
		byte	$1c	' ..###...
		byte	$20	' .....#..
		byte	$1e	' .####...

				' chr($74)
		byte	$08	' ...#....
		byte	$08	' ...#....
		byte	$28	' ...#.#..
		byte	$10	' ....#...

				' chr($75)
		byte	$22	' .#...#..
		byte	$22	' .#...#..
		byte	$32	' .#..##..
		byte	$2c	' ..##.#..

				' chr($76)
		byte	$22	' .#...#..
		byte	$22	' .#...#..
		byte	$14	' ..#.#...
		byte	$08	' ...#....

				' chr($77)
		byte	$22	' .#...#..
		byte	$2a	' .#.#.#..
		byte	$2a	' .#.#.#..
		byte	$14	' ..#.#...

				' chr($78)
		byte	$14	' ..#.#...
		byte	$08	' ...#....
		byte	$14	' ..#.#...
		byte	$22	' .#...#..

				' chr($79)
		byte	$22	' .#...#..
		byte	$22	' .#...#..
		byte	$3c	' ..####..
		byte	$20	' .....#..

				' chr($7a)
		byte	$10	' ....#...
		byte	$08	' ...#....
		byte	$04	' ..#.....
		byte	$3e	' .#####..

				' chr($7b)
		byte	$04	' ..#.....
		byte	$08	' ...#....
		byte	$08	' ...#....
		byte	$10	' ....#...

				' chr($7c)
		byte	$00	' ........
		byte	$08	' ...#....
		byte	$08	' ...#....
		byte	$08	' ...#....

				' chr($7d)
		byte	$10	' ....#...
		byte	$08	' ...#....
		byte	$08	' ...#....
		byte	$04	' ..#.....

				' chr($7e)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($7f)
		byte	$2a	' .#.#.#..
		byte	$14	' ..#.#...
		byte	$2a	' .#.#.#..
		byte	$14	' ..#.#...

				' chr($80)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($81)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($82)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($83)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($84)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($85)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($86)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($87)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($88)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($89)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($8a)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($8b)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($8c)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($8d)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($8e)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($8f)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($90)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($91)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($92)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($93)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($94)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($95)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($96)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($97)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($98)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($99)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($9a)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($9b)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($9c)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($9d)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($9e)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($9f)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($a0)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($a1)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($a2)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($a3)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($a4)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($a5)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($a6)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($a7)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($a8)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($a9)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($aa)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($ab)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($ac)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($ad)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($ae)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($af)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($b0)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($b1)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($b2)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($b3)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($b4)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($b5)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($b6)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($b7)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($b8)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($b9)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($ba)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($bb)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($bc)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($bd)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($be)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($bf)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($c0)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($c1)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($c2)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($c3)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($c4)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($c5)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($c6)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($c7)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($c8)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($c9)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($ca)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($cb)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($cc)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($cd)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($ce)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($cf)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($d0)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($d1)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($d2)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($d3)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($d4)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($d5)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($d6)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($d7)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($d8)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($d9)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($da)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($db)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($dc)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($dd)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($de)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($df)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($e0)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($e1)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($e2)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($e3)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($e4)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($e5)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($e6)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($e7)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($e8)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($e9)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($ea)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($eb)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($ec)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($ed)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($ee)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($ef)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($f0)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($f1)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($f2)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($f3)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($f4)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($f5)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($f6)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($f7)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($f8)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($f9)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($fa)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($fb)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($fc)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($fd)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($fe)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($ff)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($00)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($01)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($02)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($03)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($04)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($05)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($06)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($07)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($08)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($09)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($0a)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($0b)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($0c)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($0d)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($0e)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($0f)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($10)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($11)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($12)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($13)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($14)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($15)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($16)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($17)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($18)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($19)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($1a)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($1b)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($1c)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($1d)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($1e)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($1f)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($20)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($21)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($22)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($23)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($24)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($25)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($26)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($27)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($28)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($29)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($2a)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($2b)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($2c)
		byte	$04	' ..#.....
		byte	$02	' .#......
		byte	$00	' ........
		byte	$00	' ........

				' chr($2d)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($2e)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($2f)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($30)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($31)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($32)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($33)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($34)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($35)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($36)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($37)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($38)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($39)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($3a)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($3b)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($3c)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($3d)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($3e)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($3f)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($40)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($41)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($42)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($43)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($44)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($45)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($46)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($47)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($48)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($49)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($4a)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($4b)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($4c)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($4d)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($4e)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($4f)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($50)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($51)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($52)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($53)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($54)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($55)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($56)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($57)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($58)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($59)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($5a)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($5b)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($5c)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($5d)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($5e)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($5f)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($60)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($61)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($62)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($63)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($64)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($65)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($66)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($67)
		byte	$22	' .#...#..
		byte	$1c	' ..###...
		byte	$00	' ........
		byte	$00	' ........

				' chr($68)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($69)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($6a)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($6b)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($6c)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($6d)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($6e)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($6f)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($70)
		byte	$02	' .#......
		byte	$02	' .#......
		byte	$00	' ........
		byte	$00	' ........

				' chr($71)
		byte	$20	' .....#..
		byte	$20	' .....#..
		byte	$00	' ........
		byte	$00	' ........

				' chr($72)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($73)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($74)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($75)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($76)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($77)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($78)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($79)
		byte	$22	' .#...#..
		byte	$1c	' ..###...
		byte	$00	' ........
		byte	$00	' ........

				' chr($7a)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($7b)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($7c)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($7d)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($7e)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($7f)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($80)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($81)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($82)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($83)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($84)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($85)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($86)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($87)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($88)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($89)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($8a)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($8b)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($8c)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($8d)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($8e)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($8f)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($90)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($91)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($92)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($93)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($94)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($95)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($96)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($97)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($98)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($99)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($9a)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($9b)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($9c)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($9d)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($9e)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($9f)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($a0)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($a1)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($a2)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($a3)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($a4)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($a5)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($a6)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($a7)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($a8)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($a9)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($aa)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($ab)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($ac)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($ad)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($ae)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($af)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($b0)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($b1)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($b2)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($b3)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($b4)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($b5)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($b6)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($b7)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($b8)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($b9)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($ba)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($bb)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($bc)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($bd)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($be)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($bf)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($c0)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($c1)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($c2)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($c3)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($c4)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($c5)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($c6)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($c7)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($c8)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($c9)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($ca)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($cb)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($cc)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($cd)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($ce)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($cf)
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........
		byte	$00	' ........

				' chr($d0)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($d1)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($d2)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($d3)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($d4)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($d5)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($d6)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($d7)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($d8)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($d9)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($da)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($db)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($dc)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($dd)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($de)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($df)
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....
		byte	$07	' ###.....

				' chr($e0)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($e1)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($e2)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($e3)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($e4)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($e5)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($e6)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($e7)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($e8)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($e9)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($ea)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($eb)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($ec)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($ed)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($ee)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($ef)
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..
		byte	$38	' ...###..

				' chr($f0)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($f1)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($f2)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($f3)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($f4)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($f5)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($f6)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($f7)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($f8)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($f9)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($fa)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($fb)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($fc)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($fd)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($fe)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

				' chr($ff)
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..
		byte	$3f	' ######..

{{
+------------------------------------------------------------------------------------------------------------------------------+
|				    TERMS OF USE: Parallax Object Exchange License					       |
+------------------------------------------------------------------------------------------------------------------------------+
|Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation    | |files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,    |
|modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software|
|is furnished to do so, subject to the following conditions:                                                                   |
|                                                                                                                              |
|The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.|
|                                                                                                                              |
|THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE	       |
|WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR         |
|COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,   |
|ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.                         |
+------------------------------------------------------------------------------------------------------------------------------+
}}
