'******************************************************************************
'*  trs80.spin - Demo mode for the TRS80 video and render cogs
'*
'*  (c) Juergen Buchmueller <pullmoll@t-online.de>
'*
'* $Id$
'******************************************************************************
CON
	_xinfreq		= 5_000_000		' Quartz is 5MHz
	_clkmode		= xtal1 + pll16x	' System clock is 80MHz

' Memory access dispatch tables for TRS-80 in yaz80
#define TRS80

'#define NTSC
#define PAL

'#define TriBladeProp
'#define RamBladeProp
#define DracBladeProp

' Uncomment to have debug code inserted
'#define DEBUG

' Uncomment to emulate interrupts (NMI and IRQ)
'#define INTERRUPTS

' Uncomment to emulate undocumented X and Y flags (partially)
'#define XYFLAGS

' Uncomment to count cycles
'#define COUNT_C

' Uncomment to count R register
#define COUNT_R


#ifdef TriBladeProp
' serial I/O pins on the TriBladeProp #2
	SI			= 31
	SO			= 30
' SD pins on the TriBladeProp #2
	doPin			= 9
	clkPin			= 28
	diPin			= 8
	csPin			= 14
' TV out pin
	tvPin			= 14
' Keyboard pins
	kbDpin			= 26
	kbCpin			= 27
#endif

#ifdef RamBladeProp
' serial I/O pins on the RamBladeProp
	SI			= 23
	SO			= 22
' microSD pins on RamBladeProp
	doPin			= 24
	clkPin			= 26
	diPin			= 25
	csPin			= 19
' TV out pin
	tvPin			= 14
' Keyboard pins
	kbDpin			= 26
	kbCpin			= 27
#endif

#ifdef DracBladeProp
' serial I/O pins on the DracBladeProp
	SI			= 31
	SO			= 30
' SD pins on the DracBladeProp
	doPin			= 12
	clkPin			= 13
	diPin			= 14
	csPin			= 15
' TV out pin
	tvPin			= 18
' Keyboard pins
	kbDpin			= 26
	kbCpin			= 27
#endif


OBJ
        render	: "trs80_render"
	video	: "trs80_video"
	yaz80	: "yaz80"
	io	: "io"
#ifdef TriBladeProp
	xmm	: "TriBladeProp_Blade2_204"		' Extended memory manager
#endif
#ifdef RamBladeProp
	xmm	: "RamBlade_203_002"			' Extended memory manager
#endif
#ifdef DracBladeProp
	xmm	: "Dracblade"				' Extended memory manager
#endif
VAR
	long	params[4]
	long	seed
	long	curx
	long	cury

PUB     main : okay | i, j, w
	params[0] := @sync_				' rendezvous: scanrow counter
	params[1] := @videoram_				' 1K video RAM
	params[2] := @bitmaps_				' 2 scanline bitmap
	params[3] := tvPin				' video pin
	io.start(SI, SO, doPin, clkPin, diPin, csPin, kbDpin, kbCpin, @videoram_)
	video.start(@params)
        render.start(@params)
	okay := yaz80.start(0, io.command_addr, @videoram_, 0)
	if okay < 0
		return
	bytemove(params[1], string("Z80 powered up"), 14)
	repeat while 1

PUB chr(ch)
	if ch == 13
		curx := 64
	else
		videoram_[cury*64+curx] := ch
		curx++
	if curx == 64
		curx := 0
		cury++
		if cury == 16
			longmove(params[1], params[1] + 64, 64*15/4)
			longfill(params[1] + 64*15, $20202020, 64/4)
			cury := 15

PUB str(stringptr)
'' Print a zero-terminated string
	repeat strsize(stringptr)
		chr(byte[stringptr++])

PUB hex(value, digits)
'' Print a hexadecimal number to the PST
	value <<= (8 - digits) << 2
	repeat digits
		chr(lookupz((value <-= 4) & $F : "0".."9", "A".."F"))

DAT
sync_		long    0
bitmaps_	byte	0[2*64*6/8]
videoram_	byte	0[64*16]
